@@ -6,12 +6,17 @@ module Main where
 
 import Control.Concurrent
 import Control.Exception
+import Data.List
 import qualified System.Remote.Counter as Counter
 import qualified System.Remote.Label as Label
 import System.Remote.Monitoring
 
+-- 'sum' is using a non-strict lazy fold and will blow the stack.
+sum' :: Num a => [a] -> a
+sum' = foldl' (+) 0
+
 mean :: Fractional a => [a] -> a
-mean xs = sum xs / fromIntegral (length xs)
+mean xs = sum' xs / fromIntegral (length xs)
 
 main :: IO ()
 main = do
